@@ -34,7 +34,7 @@ class StandardAPIView(BaseAPIView):
 
     def paginate_data(self, data, request, serializer_class=None, context=None, **kwargs):
         # Create a paginator instance
-        paginator = self.pagination_class(page_size=self.pagination_class.page_size, max_page_size=self.pagination_class.max_page_size)
+        paginator = self.pagination_class(**kwargs)
 
         # Paginate the data object and return the paginated response
         paginated_data = paginator.paginate_data(data, request)
@@ -99,6 +99,7 @@ class HelloWorldPaginatedView(StandardAPIView):
 #     def get(self, request, format=None):
 #         courses = Courses.objects.all()
 #         if courses:
-#             return self.paginate_data(courses, request, page_size=3, max_page_size=5)
+#             serializer_class = CourseSerializer
+#             return self.paginate_data(courses, request, serializer_class)
 #         else:
 #             return self.send_error('No data found')
\ No newline at end of file
